==> 1.1.1.tar.gz: lib/widget/source/app_root.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_keyboard_visibility/flutter_keyboard_visibility.dart';
import 'package:getx_extended/controller/source/task_controller.dart';
import 'package:getx_extended/export.dart';

class AppRoot extends StatefulWidget {
  Widget child;
  Widget Function(bool isKeyboardVisible) keyboardToolbar;
  Widget loading;
  Future Function(dynamic error) consumeError;

  AppRoot({
    required this.child,
    required this.keyboardToolbar,
    required this.loading,
    required this.consumeError,
  });

  @override
  _AppRootState createState() => _AppRootState();
}

class _AppRootState extends State<AppRoot> with AutoDisposableState {
  late TaskController _task = Get.find();

  @override
  void initState() {
    super.initState();
    autoDispose(_task.errors.listen((_) => _checkError()));
  }

  dynamic _currentError;

  void _checkError() {
    final error = _task.errors.firstOrNull;
    if (error == null || _currentError == error) return;
    _currentError = error;
    postFrameFuture(() async {
      await widget.consumeError(error);
      _currentError = null;
      _task.dismiss(error);
    });
  }

  @override
  Widget build(BuildContext context) => Scaffold(
        body: SafeArea(
          child: KeyboardVisibilityBuilder(
            builder: (_, isKeyboardVisible) => Column(
              children: [
                Expanded(
                  child: Stack(
                    children: [
                      widget.child,
                      _task.isProcessing.toWidget(
                        (rx) => rx.value ? widget.loading : Container(),
                      )
                    ],
                  ),
                ),
                widget.keyboardToolbar(isKeyboardVisible)
              ],
            ),
          ),
        ),
      );
}

==> 1.4.3.tar.gz: lib/widget/source/app_root.dart <==
import 'dart:async';

import 'package:flutter/material.dart';
import 'package:flutter_keyboard_visibility/flutter_keyboard_visibility.dart';
import 'package:getx_extended/controller/source/task_controller.dart';
import 'package:getx_extended/export.dart';

class AppRoot extends StatefulWidget {
  Widget child;
  Widget Function(bool isKeyboardVisible) keyboardToolbar;
  Widget loading;
  Future Function(dynamic error) consumeError;

  AppRoot({
    required this.child,
    required this.keyboardToolbar,
    required this.loading,
    required this.consumeError,
  });

  @override
  _AppRootState createState() => _AppRootState();
}

class _AppRootState extends State<AppRoot> with AutoDisposableState {
  late TaskController _task = Get.find();

  @override
  void initState() {
    super.initState();
    autoDispose(_task.errors.listen((_) => _checkError()));
  }

  dynamic _currentError;

  void _checkError() {
    final error = _task.errors.firstOrNull;
    if (error == null || _currentError == error) return;
    _currentError = error;
    postFrameFuture(() async {
      await widget.consumeError(error);
      _currentError = null;
      _task.dismiss(error);
    });
  }

  @override
  Widget build(BuildContext context) =>
      Scaffold(
        body: KeyboardVisibilityBuilder(
          builder: (_, isKeyboardVisible) =>
              SafeArea(
                top: false,
                bottom: isKeyboardVisible,
                child: Column(
                  children: [
                    Expanded(
                      child: Stack(
                        children: [
                          widget.child,
                          _task.isProcessing.toWidget(
                                (rx) => rx.value ? widget.loading : Container(),
                          )
                        ],
                      ),
                    ),
                    widget.keyboardToolbar(isKeyboardVisible)
                  ],
                ),
              ),
        ),
      );
}
